# retentioneering-tools

## Installation

### Python and Jupyter

Firstly, you need to install python and Jupyter.
We supports only python 3.
For quick start better to install [Anaconda](https://www.anaconda.com/).

### Python package

- You can install our package using pip.

```bash
pip3 install retentioneering
```

- Or directly from source

    ```bash
    git clone path-to-our-rep.git
    cd retentioneering-framework
    python3 setup.py install --user
    ```
    
### First steps

To start use our package, please, see the [documentation](https://retentioneering.github.io/retentioneering-tools/) 

        
